@@ -1,5 +1,5 @@
 // rak - Rakshasa's toolbox
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -108,8 +108,8 @@ public:
     return *this;
   }
 
-  bool operator == (const split_iterator_t& itr) const { return m_pos == m_seq->end(); }
-  bool operator != (const split_iterator_t& itr) const { return m_pos != m_seq->end(); }
+  bool operator == (__UNUSED const split_iterator_t& itr) const { return m_pos == m_seq->end(); }
+  bool operator != (__UNUSED const split_iterator_t& itr) const { return m_pos != m_seq->end(); }
 
 private:
   const Sequence* m_seq;
@@ -126,7 +126,7 @@ split_iterator(const Sequence& seq, typename Sequence::value_type delim) {
 
 template <typename Sequence>
 inline split_iterator_t<Sequence>
-split_iterator(const Sequence& seq) {
+split_iterator(__UNUSED const Sequence& seq) {
   return split_iterator_t<Sequence>();
 }
 
