@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -102,8 +102,14 @@ File::close() {
 
 // Reserve the space on disk if a system call is defined. 'length'
 // of zero indicates to the end of the file.
+#if !defined(USE_XFS) && !defined(USE_POSIX_FALLOCATE)
+#define RESERVE_PARAM __UNUSED
+#else
+#define RESERVE_PARAM
+#endif
+
 bool
-File::reserve(off_t offset, off_t length) {
+File::reserve(RESERVE_PARAM off_t offset, RESERVE_PARAM off_t length) {
 #ifdef USE_XFS
   struct xfs_flock64 flock;
 
@@ -122,6 +128,8 @@ File::reserve(off_t offset, off_t length) {
 #endif
 }
 
+#undef RESERVE_PARAM
+
 off_t
 File::size() const {
   if (!is_open())
