@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -76,7 +76,7 @@ ChunkSelector::update_priorities() {
 }
 
 uint32_t
-ChunkSelector::find(PeerChunks* peerChunks, bool highPriority) {
+ChunkSelector::find(PeerChunks* peerChunks, __UNUSED bool highPriority) {
   if (m_position == invalid_chunk)
     return m_position;
 
@@ -126,11 +126,11 @@ ChunkSelector::not_using_index(uint32_t index) {
 }
 
 void
-ChunkSelector::insert_peer_chunks(PeerChunks* peerChunks) {
+ChunkSelector::insert_peer_chunks(__UNUSED PeerChunks* peerChunks) {
 }
 
 void
-ChunkSelector::erase_peer_chunks(PeerChunks* peerChunks) {
+ChunkSelector::erase_peer_chunks(__UNUSED PeerChunks* peerChunks) {
 }
 
 inline uint32_t
@@ -160,7 +160,7 @@ ChunkSelector::search_range(const BitField* bf, uint32_t first, uint32_t last) {
   BitField::const_iterator source = bf->begin() + first / 8;
 
   // Unset any bits before 'first'.
-  BitField::data_t wanted = (*source & *local) & (~(BitField::data_t)0 >> (first % 8));
+  BitField::data_t wanted = (*source & *local) & (0xff >> (first % 8));
 
   while (wanted == 0) {
     ++local;
@@ -174,6 +174,9 @@ ChunkSelector::search_range(const BitField* bf, uint32_t first, uint32_t last) {
   
   uint32_t position = m_bitfield.position(local) + search_byte(wanted);
 
+  if (position < first)
+    throw internal_error("ChunkSelector::search_range(...) position < first.");
+
   if (position < last)
     return position;
   else
