@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -75,12 +75,11 @@ DownloadWrapper::~DownloadWrapper() {
 }
 
 void
-DownloadWrapper::initialize(const std::string& hash, const std::string& id, const SocketAddress& sa) {
+DownloadWrapper::initialize(const std::string& hash, const std::string& id) {
   m_main.slot_hash_check_add(rak::make_mem_fun(this, &DownloadWrapper::check_chunk_hash));
 
   m_main.tracker_manager()->tracker_info()->set_hash(hash);
   m_main.tracker_manager()->tracker_info()->set_local_id(id);
-  m_main.tracker_manager()->tracker_info()->set_local_address(sa);
   m_main.tracker_manager()->tracker_info()->set_key(random());
   m_main.tracker_manager()->slot_success(rak::make_mem_fun(this, &DownloadWrapper::receive_tracker_success));
   m_main.tracker_manager()->slot_failed(rak::make_mem_fun(this, &DownloadWrapper::receive_tracker_failed));
@@ -306,9 +305,14 @@ DownloadWrapper::get_local_id() const {
   return m_main.tracker_manager()->tracker_info()->get_local_id();
 }
 
+SocketAddress&
+DownloadWrapper::bind_address() {
+  return m_main.tracker_manager()->tracker_info()->bind_address();
+}
+
 SocketAddress&
 DownloadWrapper::local_address() {
-  return m_main.tracker_manager()->tracker_info()->get_local_address();
+  return m_main.tracker_manager()->tracker_info()->local_address();
 }
 
 void
