@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -99,6 +99,9 @@ Manager::~Manager() {
 
 void
 Manager::initialize_download(DownloadWrapper* d) {
+  d->bind_address() = m_bindAddress;
+  d->local_address() = m_localAddress;
+
   d->set_handshake_manager(m_handshakeManager);
   d->set_hash_queue(m_hashQueue);
   d->set_file_manager(m_fileManager);
@@ -133,7 +136,7 @@ Manager::receive_tick() {
 
   // If you change the interval, make sure the above keepalive gets
   // triggered every 120 seconds.
-  priority_queue_insert(&taskScheduler, &m_taskTick, (cachedTime + 30 * 1000000).round_seconds());
+  priority_queue_insert(&taskScheduler, &m_taskTick, (cachedTime + rak::timer::from_seconds(30)).round_seconds());
 }
 
 void
