@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -62,7 +62,7 @@ SocketManager::open(const SocketAddress& sa, const SocketAddress& b) {
 }
 
 SocketFd
-SocketManager::received(SocketFd fd, const SocketAddress& sa) {
+SocketManager::received(SocketFd fd, __UNUSED const SocketAddress& sa) {
   if (!fd.is_valid())
     throw internal_error("SocketManager::received(...) received an invalid file descriptor");
 
