@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ Handshake::Handshake(SocketFd fd, HandshakeManager* m) :
 
   m_taskTimeout.set_slot(rak::mem_fn(this, &Handshake::send_failed));
 
-  priority_queue_insert(&taskScheduler, &m_taskTimeout, (cachedTime + 60 * 1000000).round_seconds());
+  priority_queue_insert(&taskScheduler, &m_taskTimeout, (cachedTime + rak::timer::from_seconds(60)).round_seconds());
 }
 
 Handshake::~Handshake() {
