@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -90,7 +90,7 @@ PeerConnectionLeech::receive_finished_chunk(int32_t index) {
 
 bool
 PeerConnectionLeech::receive_keepalive() {
-  if (cachedTime - m_timeLastRead > 240 * 1000000)
+  if (cachedTime - m_timeLastRead > rak::timer::from_seconds(240))
     return false;
 
   // There's no point in adding ourselves to the write poll if the
