@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -146,7 +146,7 @@ ResourceManager::balance_unchoked(unsigned int weight) {
     // Consider skipping the leading zero interested downloads.
     sort(begin(), end(), resource_manager_interested_increasing());
 
-    for (iterator itr = begin(); itr != end(); ++itr) {
+    for (iterator itr = begin(); weight != 0 && itr != end(); ++itr) {
       m_currentlyUnchoked += itr->second->choke_manager()->cycle((quota * itr->first) / weight);
       quota -= itr->second->choke_manager()->currently_unchoked();
       weight -= itr->first;
