@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -110,6 +110,9 @@ Bencode::clear() {
 
 Bencode&
 Bencode::operator = (const Bencode& b) {
+  if (&b == this)
+    return *this;
+
   clear();
 
   m_type = b.m_type;
