@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -185,7 +185,7 @@ set_local_address(const std::string& addr) {
     throw input_error("Tried to set an invalid/non-existent local address.");
 
   for (DownloadManager::const_iterator itr = manager->download_manager()->begin(), last = manager->download_manager()->end(); itr != last; ++itr)
-    (*itr)->local_address().set_address(manager->local_address()->get_address());
+    (*itr)->local_address() = *manager->local_address();
 }
 
 std::string
@@ -206,6 +206,9 @@ set_bind_address(const std::string& addr) {
 
   else if (!manager->bind_address()->set_hostname(addr))
     throw input_error("Tried to set an invalid/non-existent bind address.");
+
+  for (DownloadManager::const_iterator itr = manager->download_manager()->begin(), last = manager->download_manager()->end(); itr != last; ++itr)
+    (*itr)->bind_address() = *manager->bind_address();
 }
 
 uint32_t
@@ -220,10 +223,10 @@ next_timeout() {
   if (!taskScheduler.empty())
     return std::max(taskScheduler.top()->time() - cachedTime, rak::timer()).usec();
   else
-    return 60 * 1000000;
+    return rak::timer::from_seconds(60).usec();
 }
 
-int
+int32_t
 down_throttle() {
   return manager->download_throttle()->max_rate();
 }
@@ -236,7 +239,7 @@ set_down_throttle(int32_t bytes) {
   return manager->download_throttle()->set_max_rate(bytes);
 }
 
-int
+int32_t
 up_throttle() {
   return manager->upload_throttle()->max_rate();
 }
@@ -381,8 +384,7 @@ download_add(std::istream* s) {
   ctor.initialize(d->bencode());
 
   d->initialize(d->bencode().get_key("info").compute_sha1(),
-		PEER_NAME + rak::generate_random<std::string>(20 - std::string(PEER_NAME).size()),
-		*manager->local_address());
+		PEER_NAME + rak::generate_random<std::string>(20 - std::string(PEER_NAME).size()));
 
   // Default PeerConnection factory functions.
   d->main()->connection_list()->slot_new_connection(&createPeerConnectionDefault);
@@ -431,7 +433,7 @@ download_set_priority(Download d, uint32_t pri) {
   if (itr == manager->resource_manager()->end())
     throw client_error("torrent::download_set_priority(...) could not find the download in the resource manager.");
 
-  if (pri == 0 || pri > 1024)
+  if (pri > 1024)
     throw client_error("torrent::download_set_priority(...) received an invalid priority.");
 
   manager->resource_manager()->set_priority(itr, pri);
