@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -71,12 +71,12 @@ TrackerUdp::send_state(TrackerInfo::State state,
   close();
 
   if (!parse_url())
-    return receive_failed("Could not parse UDP hostname or port");
+    return receive_failed("Could not parse UDP hostname or port.");
 
   if (!get_fd().open_datagram() ||
       !get_fd().set_nonblock() ||
-      !get_fd().bind(m_bindAddress))
-    return receive_failed("Could not open UDP socket");
+      !get_fd().bind(m_info->bind_address()))
+    return receive_failed("Could not open UDP socket.");
 
   m_readBuffer = new ReadBuffer;
   m_writeBuffer = new WriteBuffer;
@@ -94,7 +94,7 @@ TrackerUdp::send_state(TrackerInfo::State state,
   pollCustom->insert_error(this);
 
   m_tries = m_info->udp_tries();
-  priority_queue_insert(&taskScheduler, &m_taskTimeout, (cachedTime + m_info->udp_timeout() * 1000000).round_seconds());
+  priority_queue_insert(&taskScheduler, &m_taskTimeout, (cachedTime + rak::timer::from_seconds(m_info->udp_timeout())).round_seconds());
 }
 
 void
@@ -138,7 +138,7 @@ TrackerUdp::receive_timeout() {
   if (--m_tries == 0) {
     receive_failed("Unable to connect to UDP tracker.");
   } else {
-    priority_queue_insert(&taskScheduler, &m_taskTimeout, (cachedTime + m_info->udp_timeout() * 1000000).round_seconds());
+    priority_queue_insert(&taskScheduler, &m_taskTimeout, (cachedTime + rak::timer::from_seconds(m_info->udp_timeout())).round_seconds());
 
     pollCustom->insert_write(this);
   }
@@ -167,7 +167,7 @@ TrackerUdp::event_read() {
     prepare_announce_input();
 
     priority_queue_erase(&taskScheduler, &m_taskTimeout);
-    priority_queue_insert(&taskScheduler, &m_taskTimeout, (cachedTime + m_info->udp_timeout() * 1000000).round_seconds());
+    priority_queue_insert(&taskScheduler, &m_taskTimeout, (cachedTime + rak::timer::from_seconds(m_info->udp_timeout())).round_seconds());
 
     m_tries = m_info->udp_tries();
     pollCustom->insert_write(this);
@@ -250,10 +250,10 @@ TrackerUdp::prepare_announce_input() {
   m_writeBuffer->write_64(m_sendUp);
   m_writeBuffer->write_32(m_sendState);
 
-  m_writeBuffer->write_32(m_info->get_local_address().get_addr_in_addr());
+  m_writeBuffer->write_32(m_info->local_address().get_addr_in_addr());
   m_writeBuffer->write_32(m_info->get_key());
   m_writeBuffer->write_32(m_info->get_numwant());
-  m_writeBuffer->write_16(m_info->get_local_address().get_port());
+  m_writeBuffer->write_16(m_info->local_address().get_port());
 
   m_writeBuffer->prepare_end();
 
